oos_standardize: Standardize columns to zero mean and unit variance

View source: R/oos_helpers.R

oos_standardizeR Documentation

Standardize columns to zero mean and unit variance

Description

Standardize columns to zero mean and unit variance

Usage

oos_standardize(X)

Arguments

X

A numeric matrix.

Value

A matrix with the same dimensions as X, where each column has been centred and scaled to unit variance.

Examples

X <- matrix(rnorm(100), 20, 5)
Xs <- oos_standardize(X)
round(colMeans(Xs), 10)
round(apply(Xs, 2, sd), 10)


sdim documentation built on July 15, 2026, 1:10 a.m.