Selects the lag order for an autoregressive model of the horizon-h
target \(y_{t,h}\) by minimising the Schwarz Information Criterion.
Examples
y <- rnorm(200)
select_ar_lag_sic(y, h = 1, p_max = 4)
#> [1] 1
Selects the lag order for an autoregressive model of the horizon-h
target \(y_{t,h}\) by minimising the Schwarz Information Criterion.
y <- rnorm(200)
select_ar_lag_sic(y, h = 1, p_max = 4)
#> [1] 1