Skip to contents

Monthly Fama-French 5-factor returns plus momentum and liquidity, from the replication package of He, Huang, Li, Zhou (2023). The risk-free rate (RF) column is used in the replication scripts to convert gross returns to excess returns.

Usage

he2023_ff5

Format

A data.frame with 652 rows and 9 variables:

date

First day of each month, class Date.

Mkt-RF

Market excess return (percent).

SMB

Small-minus-big size factor (percent).

HML

High-minus-low value factor (percent).

RMW

Robust-minus-weak profitability factor (percent).

CMA

Conservative-minus-aggressive investment factor (percent).

RF

Risk-free rate (percent).

FFMOM

Fama-French momentum factor (percent).

Pastor_Liq

Pastor-Stambaugh liquidity factor (percent).

He, Huang, Li, Zhou (2023) replication package, https://pubsonline.informs.org/doi/10.1287/mnsc.2022.4563.

Note

Sample period is 1963-07-01 to 2017-10-01 (652 months). Row 127 corresponds to 1974-01-01, aligning with the start of he2023_factors. To extract the matching RF series use he2023_ff5$RF[127:642].

References

He, J., Huang, J., Li, F., and Zhou, G. (2023). Shrinking Factor Dimension: A Reduced-Rank Approach. Management Science, 69(9). doi:10.1287/mnsc.2022.4563

Examples

head(he2023_ff5)
#>         date Mkt-RF   SMB   HML   RMW   CMA   RF FFMOM Pastor_Liq
#> 1 1963-07-01  -0.39 -0.46 -0.81  0.72 -1.16 0.27  0.99         NA
#> 2 1963-08-01   5.07 -0.81  1.65  0.42 -0.40 0.25  1.08         NA
#> 3 1963-09-01  -1.57 -0.48  0.19 -0.80  0.23 0.27  0.13         NA
#> 4 1963-10-01   2.53 -1.29 -0.09  2.75 -2.26 0.29  3.14         NA
#> 5 1963-11-01  -0.85 -0.85  1.71 -0.34  2.22 0.27 -0.75         NA
#> 6 1963-12-01   1.83 -1.87 -0.10  0.18 -0.31 0.29  1.70         NA