R/sdim_fit.R
predict.sdim_fit.Rd
Project new data onto estimated factor loadings
# S3 method for class 'sdim_fit' predict(object, newdata, ...)
An object of class "sdim_fit".
"sdim_fit"
A numeric matrix or data frame with the same number of columns as the original predictor matrix.
Additional arguments (currently ignored).
A numeric matrix of projected factors with nrow(newdata) rows and ncol(object$factors) columns.
nrow(newdata)
ncol(object$factors)