| predict.sdim_fit | R Documentation |
Project new data onto estimated factor loadings
## S3 method for class 'sdim_fit'
predict(object, newdata, ...)
object |
An object of class |
newdata |
A numeric matrix or data frame with the same number of columns as the original predictor matrix. |
... |
Additional arguments (currently ignored). |
A numeric matrix of projected factors with nrow(newdata) rows
and ncol(object$factors) columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.