| predict.sdim_spca | R Documentation |
Standardizes newdata using the training column means and standard
deviations, scales by the estimated (possibly winsorized) regression slopes,
and projects onto the sPCA loadings.
## S3 method for class 'sdim_spca'
predict(object, newdata, ...)
object |
An object of class |
newdata |
A numeric matrix or data frame with the same number of columns as the original predictor matrix. |
... |
Additional arguments (currently ignored). |
A numeric matrix of projected factors with nrow(newdata) rows
and ncol(object$factors) columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.