| rra_est | R Documentation |
Implements the two-step GMM estimator of He, Huang, Li, and Zhou (2023).
Factor proxies X are rotated to maximise explanatory power for the
target return matrix target, using diagonal GMM weighting matrices.
rra_est(target, X, nfac, compute_stat = FALSE)
target |
Numeric matrix (T x N) of target variables (e.g., asset returns). A vector is coerced to a T x 1 matrix. |
X |
Numeric matrix or data frame (T x L) of factor proxies. |
nfac |
Positive integer; number of RRA factors to extract. |
compute_stat |
Logical; if |
An object of class "sdim_fit".
He, J., Huang, J., Li, F., and Zhou, G. (2023). Shrinking Factor Dimension: A Reduced-Rank Approach. Management Science, 69(9). \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1287/mnsc.2022.4563")}
set.seed(1)
X <- matrix(rnorm(100 * 8), 100, 8)
Y <- matrix(rnorm(100 * 5), 100, 5)
fit <- rra_est(target = Y, X = X, nfac = 3)
print(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.